@@ -1,11 +1,11 @@
-.calcMMt <- function(geno, availmemGb, ncpu, selected_loci, quiet)
+.calcMMt <- function(geno,  ncpu, selected_loci, quiet)
   {
     ## internal function: used only in AM  and SummaryAM
     ## calculates M %*% t(M) via C++ for out of memory calculation
-    MMt <- calculateMMt(geno=geno[["asciifileM"]], availmemGb=availmemGb,
+    MMt <- calculateMMt(geno=geno[["asciifileM"]], availmemGb=geno[["availmemGb"]],
                            ncpu=ncpu,
                            dim_of_ascii_M = geno[["dim_of_ascii_M"]],
-                           selected_loci=selected_loci, quiet = quiet, message=message)
+                           selected_loci=selected_loci, quiet = quiet )
     gc()
 
 
