@@ -1,7 +1,7 @@
 calculate_a_and_vara_batch <- function(numreps=100, geno=NULL, 
                          selectedloci = NA,
                          invMMtsqrt=NULL, transformed_a=NULL, transformed_vara=NULL,
-                         quiet = TRUE, message=message, indxNA_geno=NA)
+                         quiet = TRUE, message=message)
 {
  ## internal function to AM
  ## an Rcpp function to take dimension reduced a (BLUP) values 
@@ -17,8 +17,7 @@ calculate_a_and_vara_batch <- function(numreps=100, geno=NULL,
   fnameMt <- geno[["asciifileMt"]]
   dimsMt <- c(geno[["dim_of_ascii_M"]][2], geno[["dim_of_ascii_M"]][1])
 
-  if(!any(is.na(selectedloci))) selectedloci <- selectedloci-
- if(!is.null(indxNA_geno))  indxNA_geno = indxNA_geno - 1
+  if(!any(is.na(selectedloci))) selectedloci <- selectedloci- 1
   calculate_a_and_vara_batch_rcpp(
                     numreps = numreps, 
                     f_name_ascii=fnameMt, 
@@ -28,7 +27,7 @@ calculate_a_and_vara_batch <- function(numreps=100, geno=NULL,
                     max_memory_in_Gbytes=geno[["availmemGb"]],
                     dims=dimsMt,
                     a = transformed_a,
-                    quiet = quiet, message=message, indxNA_geno=indxNA_geno)
+                    quiet = quiet, message=message)
 
 }
 
