@@ -1,5 +1,5 @@
-constructX <- function(Zmat=NULL, fnameM=NULL, currentX=NULL, loci_indx=NULL,
-                       availmemGb=8, dim_of_ascii_M=NULL,
+constructX <- function(Zmat=NULL, fnameMt=NULL, currentX=NULL, loci_indx=NULL,
+                        dim_of_Mt=NULL,
                         map=NULL)
   {
     ## internal function for AM
@@ -12,8 +12,11 @@ constructX <- function(Zmat=NULL, fnameM=NULL, currentX=NULL, loci_indx=NULL,
    {
      return(currentX)
    } else {
-       genodat <- extract_geno(fnameM=fnameM, colnum=loci_indx,
-                           availmemGb=availmemGb, dim_of_ascii_M=dim_of_ascii_M)
+#       genodat <- extract_geno(fnameM=fnameM, colnum=loci_indx,
+#                           availmemGb=availmemGb, dim_of_ascii_M=dim_of_ascii_M)
+
+       genodat <- extract_geno_Mt(fnameMt=fnameMt, colnum=loci_indx,
+                           dim_of_Mt=dim_of_Mt)
       if(is.null(Zmat)){
          newX <- cbind(currentX, genodat)
       } else {
