@@ -1,7 +1,7 @@
   #.find_qtl <- function(Zmat=NULL, geno, availmemGb,  selected_loci, MMt, invMMt, best_ve, best_vg,
   #                     currentX,  ncpu, quiet, trait, ngpu  )
   .find_qtl <- function(Zmat=NULL, geno, availmemGb,  selected_loci, MMt, invMMt, best_ve, best_vg,
-                       currentX,  ncpu, quiet, trait, ngpu, itnum, indxNA_geno=NA)
+                       currentX,  ncpu, quiet, trait, ngpu, itnum)
   {
     ##  internal function: use by   AM
 
@@ -78,10 +78,6 @@
     }
 
 
-     # when there are missing samples, this bit becomes tricky. 
-     # I am purposely returning the dimensions of hat_a and var_hat_a back to 
-     # n_g and keeping invMMtsqrt at n_g. I'll deal with indxNA_geno 
-     # inside calculate_a_vara.
 
    
      a_and_vara  <- calculate_a_and_vara(geno = geno,
@@ -89,7 +85,7 @@
                        invMMtsqrt=MMt_sqrt_and_sqrtinv[["inverse_sqrt_MMt"]],
                        transformed_a=hat_a,
                        transformed_vara=var_hat_a,
-                       quiet=quiet, message=message, indxNA_geno=indxNA_geno)
+                       quiet=quiet, message=message)
 
      if(!quiet){
         doquiet(dat=a_and_vara[["a"]], num_markers=5, lab="BLUPs for full model")
