@@ -42,16 +42,20 @@ Eigen::MatrixXd
       os << "ERROR: Could not open  " << asciifname << std::endl;
       Rcpp::stop(os.str() );
      }
-
+   Rcpp::Rcout << " This should be paralleized .... -- REadblock " << std::endl;
    for(long rr=0; rr < (start_row + numrows_in_block) ; rr++){
       // read a line of data from ASCII file
       getline(fileIN, line);
       if(rr >= start_row){
           std::istringstream streamA(line);
+          #pragma omp parallel
+          {
+          #pragma omp for
           for(long ii=0; ii < numcols  ; ii++){
             int tmp  = line[ii] - '0'; // trick to removes ASCII character offset for numbers
             M(rowi, ii) = (double) tmp - 1;   // converting data to -1, 0, 1 
           }
+          } // end pragma omp parallel
           rowi++;
       } // end if rr
    } // end for(rr
